@@ -16,6 +16,29 @@ SPECIAL_COL_SEP = "___"
 NUMERIC_NA_TOKEN = "@"
 INVALID_NUMS_RE = r"[^\-.0-9]"
 
+
+@dataclass(frozen=True)
+class TabularArtefact:
+    best_disc_model: str = "best-disc-model"
+    mean_best_disc_model: str = "mean-best-disc-model"
+    not_best_disc_model: str = "not-best-disc-model"
+    last_epoch_model: str = "last-epoch-model"
+
+    @staticmethod
+    def artefacts():
+        return [field.default for field in fields(TabularArtefact)]
+
+
+@dataclass(frozen=True)
+class ModelFileName:
+    rtf_config_json: str = "rtf_config.json"
+    rtf_model_pt: str = "rtf_model.pt"
+
+    @staticmethod
+    def names():
+        return [field.default for field in fields(ModelFileName)]
+
+
 @dataclass(frozen=True)
 class ModelType:
     tabular: str = "tabular"
@@ -231,15 +254,38 @@ def process_datetime_data(
 
     # Convert the datetimes to
     # their equivalent timestamp values.
+
+    series = (series.view(int) / 1e9).astype(int)
+
+    # Take the mean value to re-align the data.
+    # This will help reduce the scale of the numeric
+    # data that will need to be generated. Let's just
+    # add this offset back later before casting.
+    mean_date = None
+
+    if transform_data is None:
+        mean_date = int(series.mean())
+        series -= mean_date
+    else:
+        # The mean_date should have been
+        # stored during fitting.
+        series -= transform_data["mean_date"]
+
     # Then apply the numeric data processing
     # pipeline.
-    return process_numeric_data(
-        (series.view(int) / 1e9).astype(int),
+    series, transform_data = process_numeric_data(
+        series,
         max_len=max_len,
         numeric_precision=0,
         transform_data=transform_data,
     )
 
+    # Store the `mean_date` here because `process_numeric_data`
+    # expects a None transform_data during fitting.
+    if mean_date is not None:
+        transform_data["mean_date"] = mean_date
+
+    return series, transform_data
 
 def process_categorical_data(series: pd.Series) -> pd.Series:
     # Simply convert the categorical data to string.
