@@ -102,9 +102,13 @@ class REaLSampler:
             # Attempt to transform datetime data
             # from the encoded timestamp into datetime.
             try:
-                # Multiple by 1e9 since we divided by this
+                # Add the `mean_date` that we have subtracted during
+                # fitting of the data.
+                series = synth_df[col] + self.col_transform_data[col].get("mean_date", 0)
+
+                # Multiply by 1e9 since we divided by this
                 # the original timestamp in the processing step.
-                synth_df[col] = pd.to_datetime(synth_df[col] * 1e9)
+                synth_df[col] = pd.to_datetime(series * 1e9)
             except Exception:
                 pass
 
@@ -187,8 +191,9 @@ class REaLSampler:
         if with_missing_cols:
             synth_df[with_missing_cols] = (
                 synth_df[with_missing_cols]
-                .replace("<NA>", None)
-                .replace("NaN", None)
+                .replace(f".*{NUMERIC_NA_TOKEN}+.*", "NaN", regex=True)
+                .replace("<NA>", "NaN")
+                .replace("NaN", np.nan)
             )
 
         if len(valid_idx) > 0:
@@ -210,25 +215,23 @@ class REaLSampler:
         if constrain_tokens_gen:
             generate_kwargs["prefix_allowed_tokens_fn"] = self._prefix_allowed_tokens_fn
 
-        # Make sure that the [RMASK] token will never be generated.
-        if self.model_type == ModelType.tabular:
-            RMASK_ID = self.vocab["token2id"][SpecialTokens.RMASK]
-        elif self.model_type == ModelType.relational:
-            RMASK_ID = self.vocab["decoder"]["token2id"][SpecialTokens.RMASK]
+        vocab = self.vocab if self.model_type == ModelType.tabular else self.vocab["decoder"]
 
+        # Make sure that the [RMASK] token will never be generated.
+        RMASK_ID = vocab["token2id"][SpecialTokens.RMASK]
         if generate_kwargs["suppress_tokens"] is None:
             generate_kwargs["suppress_tokens"] = [RMASK_ID]
         else:
             generate_kwargs["suppress_tokens"].append(RMASK_ID)
 
         if "bos_token_id" not in generate_kwargs:
-            generate_kwargs["bos_token_id"] = self.vocab["token2id"][SpecialTokens.BOS]
+            generate_kwargs["bos_token_id"] = vocab["token2id"][SpecialTokens.BOS]
 
         if "pad_token_id" not in generate_kwargs:
-            generate_kwargs["pad_token_id"] = self.vocab["token2id"][SpecialTokens.PAD]
+            generate_kwargs["pad_token_id"] = vocab["token2id"][SpecialTokens.PAD]
 
         if "eos_token_id" not in generate_kwargs:
-            generate_kwargs["eos_token_id"] = self.vocab["token2id"][SpecialTokens.EOS]
+            generate_kwargs["eos_token_id"] = vocab["token2id"][SpecialTokens.EOS]
 
         _samples = self.model.generate(**generate_kwargs)
 
@@ -288,6 +291,13 @@ class REaLSampler:
                 # valid numbers.
                 group_series = group_series.str.lstrip("0")
 
+                # If all values are zeros for a group, then it will be left
+                # empty. Let's explicitly set the zero value back.
+                # TODO: review other use cases that this may not be correct.
+                # For example, zero may not be in the domain of the
+                # variable `CompetitionDistance` in the Rossmann dataset.
+                group_series[group_series == ""] = 0
+
                 # If the data is still an object type, try to fix potential
                 # errors.
                 if group_series.dtype == "object":
